require 'shogun'

f_feats = Shogun::CSVFile.new "../../data/fm_train_real.dat"
f_labels = Shogun::CSVFile.new "../../data/label_train_twoclass.dat"

#![create_features]
features = Shogun::RealFeatures.new f_feats
combined_features = Shogun::CombinedFeatures.new 
combined_features.append_feature_obj features
combined_features.append_feature_obj features
combined_features.append_feature_obj features
labels = Shogun::BinaryLabels.new f_labels
#![create_features]

#![create_kernels]
kernel = Shogun::CombinedKernel.new 
k_1 = Shogun::GaussianKernel.new 10, 0.1
k_2 = Shogun::GaussianKernel.new 10, 1
k_3 = Shogun::GaussianKernel.new 10, 2
kernel.append_kernel k_1
kernel.append_kernel k_2
kernel.append_kernel k_3
#![create_kernels]

#![create_classifier]
libsvm = Shogun::LibSVM.new 
svm = Shogun::MKLClassification.new libsvm
svm.set_interleaved_optimization_enabled false
svm.set_kernel kernel
#![create_classifier]

#![create_cross_validation]
splitting_strategy = Shogun::StratifiedCrossValidationSplitting.new labels, 5
evaluation_criterium = Shogun::AccuracyMeasure.new 
cross = Shogun::CrossValidation.new svm, combined_features, labels, splitting_strategy, evaluation_criterium
cross.set_autolock false
cross.set_num_runs 2
#![create_cross_validation]

#![create_observer]
mkl_obs = Shogun::ParameterObserverCV.new true
cross.subscribe_to_parameters mkl_obs
#[!create_observer]

#![evaluate_and_get_result]
result = Shogun::CrossValidationResult.new 
result = Shogun::CrossValidationResult.obtain_from_generic cross.evaluate 
#![evaluate_and_get_result]

#![get_results]
mean = result.get_mean 
stddev = result.get_std_dev 
#![get_results]

#![get_fold_machine]
obs = mkl_obs.get_observation 0
fold = obs.get_fold 0
machine = Shogun::MKLClassification.obtain_from_generic fold.get_trained_machine 
#![get_fold_machine]

#![get_weights]
k = Shogun::CombinedKernel.obtain_from_generic machine.get_kernel 
w = k.get_subkernel_weights 
#![get_weights]
