require 'shogun'

f_feats_train = Shogun::CSVFile.new "../../data/regression_1d_sinc_features_train.dat"
f_feats_test = Shogun::CSVFile.new "../../data/regression_1d_sinc_features_test.dat"
f_labels_train = Shogun::CSVFile.new "../../data/regression_1d_sinc_labels_train.dat"
f_labels_test = Shogun::CSVFile.new "../../data/regression_1d_sinc_labels_test.dat"

#![create_features]
features_train = Shogun::RealFeatures.new f_feats_train
features_test = Shogun::RealFeatures.new f_feats_test
labels_train = Shogun::RegressionLabels.new f_labels_train
labels_test = Shogun::RegressionLabels.new f_labels_test
#![create_features]

#![create_appropriate_kernel_and_mean_function]
width = 1.0
kernel = Shogun::GaussianKernel.new features_train, features_train, width
mean_function = Shogun::ZeroMean.new 
#![create_appropriate_kernel_and_mean_function]

#![create_instance]
gauss_likelihood = Shogun::GaussianLikelihood.new 
inference_method = Shogun::ExactInferenceMethod.new kernel, features_train, mean_function, labels_train, gauss_likelihood
gp_regression = Shogun::GaussianProcessRegression.new inference_method
#![create_instance]

#![train_and_apply]
gp_regression.train 
labels_predict = gp_regression.apply_regression features_test
#![train_and_apply]

#![compute_variance]
variances = gp_regression.get_variance_vector features_test
#![compute_variance]

#![optimize_marginal_likelihood]
grad_criterion = Shogun::GradientCriterion.new 
grad = Shogun::GradientEvaluation.new gp_regression, features_train, labels_train, grad_criterion
grad.set_function inference_method
grad_selection = Shogun::GradientModelSelection.new grad
best_theta = grad_selection.select_model 
best_theta.apply_to_machine gp_regression
#![optimize_marginal_likelihood]

#![evaluate_error_and_marginal_likelihood]
eval = Shogun::MeanSquaredError.new 
mse = eval.evaluate labels_predict, labels_test
marg_ll = inference_method.get_negative_log_marginal_likelihood 
#![evaluate_error_and_marginal_likelihood]

# integration testing variables
output = labels_test.get_labels 
