require 'shogun'

f_feats_train = Shogun::CSVFile.new "../../data/classifier_binary_2d_nonlinear_features_train.dat"
f_feats_test = Shogun::CSVFile.new "../../data/classifier_binary_2d_nonlinear_features_test.dat"
f_labels_train = Shogun::CSVFile.new "../../data/classifier_binary_2d_nonlinear_labels_train.dat"
f_labels_test = Shogun::CSVFile.new "../../data/classifier_binary_2d_nonlinear_labels_test.dat"

Shogun::Math.init_random 1

#![create_features]
features_train = Shogun::RealFeatures.new f_feats_train
features_test = Shogun::RealFeatures.new f_feats_test
labels_train = Shogun::BinaryLabels.new f_labels_train
labels_test = Shogun::BinaryLabels.new f_labels_test
#![create_features]

#![add_layers]
num_feats = features_train.get_num_features 
layers = Shogun::NeuralLayers.new 
layers = layers.input num_feats
layers = layers.rectified_linear 10
layers = layers.softmax 2
all_layers = layers.done 
#![add_layers]

#![create_instance]
network = Shogun::NeuralNetwork.new all_layers
network.quick_connect 
network.initialize_neural_network 
#![create_instance]

#![set_parameters]
network.set_l2_coefficient 0.01
network.set_dropout_hidden 0.5
network.set_max_num_epochs 50
network.set_gd_mini_batch_size num_feats
network.set_gd_learning_rate 0.1
network.set_gd_momentum 0.9
#![set_parameters]

#![train_and_apply]
network.set_labels labels_train
network.train features_train
labels_predict = network.apply_binary features_test
#![train_and_apply]

#![get_params]
parameters = network.get_parameters 
#![get_params]

#![evaluate_accuracy]
am = Shogun::AccuracyMeasure.new 
accuracy = am.evaluate labels_predict, labels_test
#![evaluate_accuracy]

# additional integration testing variables
output = labels_predict.get_labels 
