require 'shogun'

f_feats_train = Shogun::CSVFile.new "../../data/regression_1d_sinc_features_train_with_9d_noise.dat"
f_feats_test = Shogun::CSVFile.new "../../data/regression_1d_sinc_features_test_with_9d_noise.dat"
f_labels_train = Shogun::CSVFile.new "../../data/regression_1d_sinc_labels_train.dat"
f_labels_test = Shogun::CSVFile.new "../../data/regression_1d_sinc_labels_test.dat"

Shogun::Math.init_random 1

#![create_features]
features_train = Shogun::RealFeatures.new f_feats_train
features_test = Shogun::RealFeatures.new f_feats_test
labels_train = Shogun::RegressionLabels.new f_labels_train
labels_test = Shogun::RegressionLabels.new f_labels_test
#![create_features]

#![add_layers]
dimensions = features_train.get_num_features 
layers = Shogun::NeuralLayers.new 
layers = layers.input dimensions
layers = layers.rectified_linear 20
layers = layers.linear 1
all_layers = layers.done 
#![add_layers]

#![create_instance]
network = Shogun::NeuralNetwork.new all_layers
network.quick_connect 
network.initialize_neural_network 
#![create_instance]

#![set_parameters]
network.set_l2_coefficient 0.1
network.set_max_num_epochs 40
network.set_epsilon 0.0
network.set_gd_learning_rate 0.1
network.set_gd_momentum 0.9
#![set_parameters]

#![train_and_apply]
network.set_labels labels_train
network.train features_train
labels_predict = network.apply_regression features_test
#![train_and_apply]

#![get_params]
parameters = network.get_parameters 
#![get_params]

#![evaluate_error]
err = Shogun::MeanSquaredError.new 
mse = err.evaluate labels_predict, labels_test
#![evaluate_error]

# additional integration testing variables
output = labels_predict.get_labels 
