require 'shogun'

f_features_p = Shogun::CSVFile.new "../../data/two_sample_test_gaussian.dat"
f_features_q = Shogun::CSVFile.new "../../data/two_sample_test_laplace.dat"

#![create_features]
features_p = Shogun::RealFeatures.new f_features_p
features_q = Shogun::RealFeatures.new f_features_q
#![create_features]

#![create_instance]
mmd = Shogun::QuadraticTimeMMD.new features_p, features_q
kernel = Shogun::GaussianKernel.new 10, 1
mmd.set_kernel kernel
alpha = 0.05
#![create_instance]

#![estimate_mmd]
mmd.set_statistic_type Shogun::ST_BIASED_FULL
statistic = mmd.compute_statistic 
#![estimate_mmd]

#![perform_test]
mmd.set_null_approximation_method Shogun::NAM_PERMUTATION
mmd.set_num_null_samples 200
threshold = mmd.compute_threshold alpha
p_value = mmd.compute_p_value statistic
#![perform_test]

#![add_kernels]
kernel1 = Shogun::GaussianKernel.new 10, 0.1
kernel2 = Shogun::GaussianKernel.new 10, 1
kernel3 = Shogun::GaussianKernel.new 10, 10
mmd.add_kernel kernel1
mmd.add_kernel kernel2
mmd.add_kernel kernel3
#![add_kernels]

#![multi_kernel]
mk = mmd.multikernel 
mk.add_kernel kernel1
mk.add_kernel kernel2
mk.add_kernel kernel2

mk_statistic = mk.compute_statistic 
mk_p_value = mk.compute_p_value 
#![multi_kernel]

#![enable_train_test_mode]
mmd.set_train_test_mode true
mmd.set_train_test_ratio 1
#![enable_train_test_mode]

#![select_kernel_single]
num_runs = 1
num_folds = 3
mmd.set_kernel_selection_strategy Shogun::KSM_CROSS_VALIDATION, num_runs, num_folds, alpha
mmd.select_kernel 
learnt_kernel_single = Shogun::GaussianKernel.obtain_from_generic mmd.get_kernel 
width = learnt_kernel_single.get_width 
#![select_kernel_single]

#![select_kernel_combined]
mmd.set_kernel_selection_strategy Shogun::KSM_MAXIMIZE_MMD, true
mmd.select_kernel 
learnt_kernel_combined = Shogun::CombinedKernel.obtain_from_generic mmd.get_kernel 
weights = learnt_kernel_combined.get_subkernel_weights 
#![select_kernel_combined]

#![perform_test_optimized]
statistic_optimized = mmd.compute_statistic 
p_value_optimized = mmd.compute_p_value statistic
#![perform_test_optimized]
